import '@holi/core/components/Screen/mock'
import { act, render, screen, waitFor } from '@testing-library/react-native'
import React from 'react'
import { MockedProvider, type MockedResponse } from '@apollo/client/testing'
import { makeEngagement } from '@holi-apps/volunteering/__tests__/helpers/generators'
import {
  SimilarVolunteeringSliderDocument,
  type SimilarVolunteeringSliderQuery,
  type SimilarVolunteeringSliderQueryVariables,
} from '@holi/api/graphql/graphql-codegen'
import { ALL_SKILLS, ALL_TOPICS } from '@holi/core/domain/shared/types'
import { VolunteeringSimilarRecosFooter } from '@holi-apps/volunteering/components/VolunteeringSimilarRecosFooter'

const mockEngagementId = '123'

const allTopics = ALL_TOPICS.slice(0, 3)
const allSkills = ALL_SKILLS.slice(0, 2)

const mockNoSimilarRecoQueries: MockedResponse<
  SimilarVolunteeringSliderQuery,
  SimilarVolunteeringSliderQueryVariables
> = {
  request: {
    query: SimilarVolunteeringSliderDocument,
    variables: {
      offset: 0,
      limit: 10,
      id: mockEngagementId,
    },
  },
  result: {
    data: {
      appVolunteering_similarRecommendations: {
        data: [],
        totalResults: 0,
      },
    },
  },
}

const mockSimilarRecoQueriesEngagements = [
  makeEngagement(allTopics, allSkills),
  makeEngagement(allTopics, allSkills),
  makeEngagement(allTopics, allSkills),
  makeEngagement(allTopics, allSkills),
  makeEngagement(allTopics, allSkills),
] as SimilarVolunteeringSliderQuery['appVolunteering_similarRecommendations']['data']

const mockSimilarRecoQueries: MockedResponse<SimilarVolunteeringSliderQuery, SimilarVolunteeringSliderQueryVariables> =
  {
    request: {
      query: SimilarVolunteeringSliderDocument,
      variables: {
        offset: 0,
        limit: 10,
        id: mockEngagementId,
      },
    },
    result: {
      data: {
        appVolunteering_similarRecommendations: {
          data: mockSimilarRecoQueriesEngagements,
          totalResults: mockSimilarRecoQueriesEngagements.length,
        },
      },
    },
  }

describe('VolunteeringSimilarRecosFooter', () => {
  describe('given no similar recommendations', () => {
    it('does not display similar recommendations', async () => {
      render(
        <MockedProvider
          addTypename={false}
          mocks={[mockNoSimilarRecoQueries]}
          defaultOptions={{
            watchQuery: { fetchPolicy: 'no-cache' },
            query: { fetchPolicy: 'no-cache' },
          }}
        >
          <VolunteeringSimilarRecosFooter engagementId={mockEngagementId} />
        </MockedProvider>
      )

      await act(async () => {
        await waitFor(() => {
          expect(screen.queryByText('recommendation.slider.title')).not.toBeOnTheScreen()
        })
      })
    })
  })

  describe('given similar recommendations', () => {
    it('does display similar recommendations', async () => {
      render(
        <MockedProvider
          mocks={[mockSimilarRecoQueries]}
          defaultOptions={{
            watchQuery: { fetchPolicy: 'no-cache' },
            query: { fetchPolicy: 'no-cache' },
          }}
          addTypename={false}
        >
          <VolunteeringSimilarRecosFooter engagementId={mockEngagementId} />
        </MockedProvider>
      )

      await act(async () => {
        await waitFor(() => {
          expect(screen.getByText('recommendation.slider.title')).toBeOnTheScreen()
          expect(screen.queryAllByTestId('volunteering-reco-slider-card')).not.toHaveLength(0)
        })
      })
    })
  })
})
