import { useMemo } from 'react'
import { ENGAGEMENT_PAGE_SIZE } from '@holi-apps/volunteering/components/VolunteeringEngagementList'
import { transformTypesenseDocumentToEngagement } from '@holi-apps/volunteering/helpers/transformTypesenseDocumentToEngagement'
import { useVolunteeringRecoTypesenseParameters } from '@holi-apps/volunteering/hooks/useVolunteeringRecoTypesenseParameters'
import { logError } from '@holi/core/errors/helpers'
import { useErrorHandling } from '@holi/core/errors/hooks'
import { useOnRefresh } from '@holi/core/refreshing/hooks/useOnRefresh'
import { useUserLanguage } from '@holi/core/screens/search/hooks/useUserLanguage'
import { useTypesensePaginationQuery } from '@holi/core/typesense/hooks/useTypesensePaginationQuery'

interface UseVolunteeringRecosTypesenseProps {
  pageSize?: number
  displayErrors?: boolean
  skip?: boolean
}

export const useVolunteeringRecosTypesense = ({
  pageSize,
  displayErrors,
  skip = false,
}: UseVolunteeringRecosTypesenseProps = {}) => {
  const { displayError } = useErrorHandling()
  const language = useUserLanguage()
  const errorHandler = displayErrors ? displayError : logError

  const { isLoadingParameters, parameters } = useVolunteeringRecoTypesenseParameters({
    pageSize: pageSize ?? ENGAGEMENT_PAGE_SIZE,
    onGeolocationError: (error) => {
      errorHandler(error, 'Error retrieving geolocation', {
        location: 'useVolunteeringRecosTypesense.useVolunteeringRecoTypesenseParameters',
      })
    },
  })

  const { state, fetchNextPage, refetch } = useTypesensePaginationQuery({
    parameters,
    skip: isLoadingParameters || skip,
    onError: (error) => {
      errorHandler(error, 'Error retrieving recommendations', {
        location: 'useVolunteeringRecosTypesense.useTypesensePaginationQuery',
      })
    },
  })

  const engagements = useMemo(
    () => state.data.map((engagement) => transformTypesenseDocumentToEngagement(engagement, language)),
    [language, state.data]
  )

  useOnRefresh(refetch)

  return {
    isLoading: state.isLoading || isLoadingParameters,
    engagements,
    canFetchMore: state.canFetchMore,
    fetchNextPage,
  }
}
